@@ -275,6 +275,7 @@ class Index:
     async def search(
         self,
         query: str,
+        *,
         offset: int = 0,
         limit: int = 20,
         filter: Optional[str | list[str | list[str]]] = None,
@@ -344,7 +345,7 @@ class Index:
         return response.json()
 
     async def get_documents(
-        self, offset: int = 0, limit: int = 20, attributes_to_retrieve: Optional[str] = None
+        self, *, offset: int = 0, limit: int = 20, attributes_to_retrieve: Optional[str] = None
     ) -> Optional[list[dict]]:
         """Get a batch documents from the index.
 
@@ -405,6 +406,7 @@ class Index:
     async def add_documents_auto_batch(
         self,
         documents: list[dict],
+        *,
         max_payload_size: int = 104857600,
         primary_key: Optional[str] = None,
     ) -> list[UpdateId]:
@@ -434,7 +436,7 @@ class Index:
         return update_ids
 
     async def add_documents_in_batches(
-        self, documents: list[dict], batch_size: int = 1000, primary_key: Optional[str] = None
+        self, documents: list[dict], *, batch_size: int = 1000, primary_key: Optional[str] = None
     ) -> list[UpdateId]:
         """Adds documents in batches to reduce RAM usage with indexing.
 
@@ -484,6 +486,7 @@ class Index:
     async def add_documents_from_file_auto_batch(
         self,
         file_path: Path | str,
+        *,
         max_payload_size: int = 104857600,
         primary_key: Optional[str] = None,
     ) -> list[UpdateId]:
@@ -516,7 +519,7 @@ class Index:
         return update_ids
 
     async def add_documents_from_file_in_batches(
-        self, file_path: Path | str, batch_size: int = 1000, primary_key: Optional[str] = None
+        self, file_path: Path | str, *, batch_size: int = 1000, primary_key: Optional[str] = None
     ) -> list[UpdateId]:
         """Adds documents form a json file in batches to reduce RAM usage with indexing.
 
@@ -569,6 +572,7 @@ class Index:
     async def update_documents_auto_batch(
         self,
         documents: list[dict],
+        *,
         max_payload_size: int = 104857600,
         primary_key: Optional[str] = None,
     ) -> list[UpdateId]:
@@ -598,7 +602,7 @@ class Index:
         return update_ids
 
     async def update_documents_in_batches(
-        self, documents: list[dict], batch_size: int = 1000, primary_key: Optional[str] = None
+        self, documents: list[dict], *, batch_size: int = 1000, primary_key: Optional[str] = None
     ) -> list[UpdateId]:
         """Update documents in batches to reduce RAM usage with indexing.
 
@@ -650,6 +654,7 @@ class Index:
     async def update_documents_from_file_auto_batch(
         self,
         file_path: Path | str,
+        *,
         max_payload_size: int = 104857600,
         primary_key: Optional[str] = None,
     ) -> list[UpdateId]:
@@ -681,7 +686,7 @@ class Index:
         return update_ids
 
     async def update_documents_from_file_in_batches(
-        self, file_path: Path | str, batch_size: int = 1000, primary_key: Optional[str] = None
+        self, file_path: Path | str, *, batch_size: int = 1000, primary_key: Optional[str] = None
     ) -> list[UpdateId]:
         """Updates documents form a json file in batches to reduce RAM usage with indexing.
 
